@@ -10,4 +10,5 @@ class EnumBarType(Enum):
     day = 4,
     week = 5,
     month = 6,
-    year = 7
+    year = 7,
+    night_am_pm = 8,
